Data Generation — bcselector 0.0.38 documentation

# Data Generation

## MatrixGenerator

class `bcselector.data_generation.` `MatrixGenerator`

  Bases: `bcselector.data_generation._BasicDataGenerator`

  Methods Summary

  `generate`([n_rows, n_basic_cols, loc, …]) |

  Methods Documentation

  `generate`(n_rows=100, n_basic_cols=10, loc=0, noise_sigmas=None, basic_cost=1, seed=None, discretize_method='uniform', discretize_bins=10)

## DataFrameGenerator

class `bcselector.data_generation.` `DataFrameGenerator`

  Bases: `bcselector.data_generation.MatrixGenerator`

  Methods Summary

  `generate`([n_rows, n_basic_cols, loc, …]) |

  Methods Documentation

  `generate`(n_rows=100, n_basic_cols=10, loc=0, noise_sigmas=None, basic_cost=1, seed=None, discretize_method='uniform', discretize_bins=10)